@@ -46,6 +46,15 @@ def before_commit(session):
         log.debug('BUG?: Database writes should not be tried when there is no database lock.')
 
 
+@sqlalchemy.event.listens_for(sqlalchemy.engine.Engine, 'connect')
+def set_sqlite_pragma(dbapi_connection, connection_record):
+    cursor = dbapi_connection.cursor()
+    # There were reported db problems with WAL mode on XFS filesystem, which is sticky and may have been turned
+    # on with certain FlexGet versions (e2c118e) #2749
+    cursor.execute('PRAGMA journal_mode=delete')
+    cursor.close()
+
+
 class Manager(object):
 
     """Manager class for FlexGet
